<?php
/**
 * Register Home Featured Slider Widgets.
 *
 * @package RT_Magazine_Plus
 */

function RT_Magazine_Plus_Home_Featured_Action_Slider() {

  register_widget( 'RT_Magazine_Plus_Home_Featured_Slider' );
  
}
add_action( 'widgets_init', 'RT_Magazine_Plus_Home_Featured_Action_Slider' );


/**
* 
*/
class RT_Magazine_Plus_Home_Featured_Slider extends WP_Widget
{
	
	function __construct()	{
		
		global $control_ops;

		$widget_ops = array(
		  'classname'   => 'featured-slider',
		  'description' => esc_html__( 'Displays latest posts or posts from a choosen category.', 'rt-magazine-plus' ),
		);		

		parent::__construct( 'RT_Magazine_Plus_Home_Featured_Slider',esc_html__( 'RT Magazine Plus: Featured Slider', 'rt-magazine-plus' ), $widget_ops, $control_ops );
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 
		  'category'         => '',		      
		  'number'           => 4,
		  'enable_content'	 => true,	 
		  'show_post_meta'	 => true,	
		) );

		$category = isset( $instance['category'] ) ? absint( $instance['category'] ) : 0;		
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 4;  
		$enable_content = isset( $instance['enable_content'] ) ? (bool) $instance['enable_content'] : true;		
		$show_post_meta = isset( $instance['show_post_meta'] ) ? (bool) $instance['show_post_meta'] : true;		
		$enable_navs = isset( $instance['enable_navs'] ) ? (bool) $instance['enable_navs'] : true;
		
	?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'category' ) ); ?>">
				<?php esc_html_e( 'Select Category:', 'rt-magazine-plus' ); ?>			
			</label>

			<?php
				wp_dropdown_categories(array(
	                'orderby'         => 'name',
	                'hide_empty'      => 0,
	                'class' 		  => 'widefat',				
					'show_option_none' => '',
					'show_option_all'  => esc_html__('&mdash; Select &mdash;','rt-magazine-plus'),
					'name'             => esc_attr($this->get_field_name( 'category' )),
					'selected'         => absint( $category ),          
				) );
			?>
		</p>		

	    <p>
	    	<label for="<?php echo esc_attr($this->get_field_id( 'number' )); ?>">
	    		<?php echo esc_html__( 'Choose Number', 'rt-magazine-plus' );?>    		
	    	</label>

	    	<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'number' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'number' )); ?>" type="number" step="1" min="1" value="<?php echo esc_attr($number); ?>" max="100" />
	    </p>
		<p>
		    <input class="checkbox" type="checkbox"<?php checked( $enable_content ); ?> id="<?php echo esc_attr($this->get_field_id( 'enable_content' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'enable_content' )); ?>" />
		    <label for="<?php echo esc_attr($this->get_field_id( 'enable_content' )); ?>">
		    	<?php echo esc_html__( 'Enable Post Content', 'rt-magazine-plus' ); ?>
		    	
		    </label>
		</p>	    

		<p>
		    <input class="checkbox" type="checkbox"<?php checked( $show_post_meta ); ?> id="<?php echo esc_attr($this->get_field_id( 'show_post_meta' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'show_post_meta' )); ?>" />
		    <label for="<?php echo esc_attr($this->get_field_id( 'show_post_meta' )); ?>">
		    	<?php echo esc_html__( 'Enable Post Meta', 'rt-magazine-plus' ); ?>
		    	
		    </label>
		</p>
		<p>
		    <input class="checkbox" type="checkbox"<?php checked( $enable_navs ); ?> id="<?php echo esc_attr($this->get_field_id( 'enable_navs' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'enable_navs' )); ?>" />
		    <label for="<?php echo esc_attr($this->get_field_id( 'enable_navs' )); ?>">
		    	<?php echo esc_html__( 'Enable Slider Nav', 'rt-magazine-plus' ); ?>
		    	
		    </label>
		</p>				


	<?php 
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['category'] = absint( $new_instance['category'] );		
		$instance['number'] = (int) $new_instance['number'];
		$instance['enable_content'] = (bool) $new_instance['enable_content'];
		$instance['show_post_meta'] = (bool) $new_instance['show_post_meta']; 
		$instance['enable_navs'] 	= (bool) $new_instance['enable_navs']; 	   

		return $instance;
	}

    function widget( $args, $instance ) {

    	extract( $args );
    	
        $category  = isset( $instance[ 'category' ] ) ? $instance[ 'category' ] : '';

        $number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 4;       

        $enable_content = isset( $instance['enable_content'] ) ? $instance['enable_content'] : true;
       
        $show_post_meta = isset( $instance['show_post_meta'] ) ? $instance['show_post_meta'] : true;

        $enable_navs = isset( $instance['enable_navs'] ) ? $instance['enable_navs'] : true;   

        echo $before_widget;

	        $slider_args = array(
	            'posts_per_page' => absint( $number ),
	            'post_type' => 'post',
	            'post_status' => 'publish',
	            'post__not_in' => get_option( 'sticky_posts' ),      
	        );

	        if ( absint( $category ) > 0 ) {
	          $slider_args['cat'] = absint( $category );
	        }
	        $the_query = new WP_Query( $slider_args ); 

	        if ($the_query->have_posts()) : $count= 0; ?>
                <div class="owl-carousel owl-theme owl-slider-demos" data-enableNavs="<?php echo esc_attr( $enable_navs);?>" id="owl-slider-demo" >
                	<?php while ( $the_query->have_posts() ) : $the_query->the_post(); $count++; ?>
                		<?php 
						$image_class = '';
						$image_size = 'rt-magazine-plus-featured-slider';							
						if( !has_post_thumbnail() ){
							$image_class= 'no-image';
						}

                		?>
						<div class="slider-content <?php echo esc_attr( $image_class);?>">

							<?php if ( has_post_thumbnail() ): ?>
								<figure class="slider-image">
									<?php the_post_thumbnail( $image_size );?>
								</figure>
							<?php endif;?>

							<?php $category = '';
								global $post;
								$category_detail=get_the_category( $post->ID );										
								foreach($category_detail as $cd){
									$category = $cd->cat_ID;
								}
							?>
							<div class="slider-text rt-magazine-plus-cat-<?php echo esc_attr( $category );?>">

								<?php rt_magazine_entry_categories(); ?>

								<h3 class="slider-title"> 
									<a href="<?php the_permalink();?>"><?php the_title();?></a> 
								</h3>

								<?php if( true == $show_post_meta ): ?>
									<div class="entry-meta">
										<?php rt_magazine_posted_by(); ?>
										<?php rt_magazine_posted_on(); ?>
									</div>
								<?php endif; ?>

								<?php if ( true == $enable_content): 
								$excerpt = rt_magazine_the_excerpt(22);
									if ( !empty( $excerpt ) ): ?>
										<div class="entry-content">
		                                    <?php	                                        
		                                        echo wp_kses_post( wpautop( $excerpt ) );
		                                    ?>
										</div>	
									<?php endif;?>
								<?php endif; ?>
							</div>
						</div> 
					<?php endwhile;
					wp_reset_postdata();?>
				</div>
	        <?php endif;

        echo $after_widget;
    } 		      		
}